from .linear import LinearApproximator
from .torch_approximator import TorchApproximator
from .cmac import CMAC

__all__ = ['LinearApproximator', 'TorchApproximator', 'CMAC']
